==> vtigercrm-5.2.1.tgz: modules/CustomView/language/fr_fr.lang.php <==
<?php
/***********************************************************
*  Module       : CustomView
*  Language     : Francais
*  Version      : 5.1.0 GA*  Created Date : 2009-06-23 21:36:13 
*  Last change  : 2009-07-21 00:49:17
*  Author       : french-vtiger.fr 
*  License      : GPL

***********************************************************/


$mod_strings = array (
		'LBL_MODULE_NAME' => 'Filtres',
		'LBL_STEP_1_TITLE' => 'Information',
		'LBL_VIEW_NAME' => 'Nom du filtre :',
		'LBL_SETDEFAULT' => 'Définir par défaut',
		'LBL_LIST_IN_METRICS' => 'Indicateur clé',
		'LBL_STEP_2_TITLE' => 'Sélectionner colonne',
		'LBL_STEP_3_TITLE' => 'Filtres standards',
		'LBL_STEP_4_TITLE' => 'Filtres avancés',
		'LBL_STEP_5_TITLE' => 'Information d\'accès',
		'LBL_SF_COLUMNS' => 'Colonne',
		'LBL_SF_STARTDATE' => 'Date de début',
		'LBL_SF_ENDDATE' => 'Date de fin',
		'LBL_AF_HDR1' => 'Définir les options de recherche.',
		'LBL_AF_HDR2' => 'Vous pouvez utiliser le filtre "or" en saisissant simplement plusieurs conditions.',
		'LBL_AF_HDR3' => 'Vous pouvez saisir jusqu\'à 10 conditions, séparées par des virgules. Par exemple : CA, NY, TX, FL pour rechercher CA ou NY ou TX ou FL.',
		'LBL_AF_HDR4' => 'Si \"Type d\'activité\" est sélectionné, donnez une de ces valeurs \"Call\",\"Meeting\" ou \"Task\".',
		'LBL_NONE' => 'Aucun',
		'View_Name' => 'Nom du filtre',
		'LBL_AND' => 'et',
		'LBL_DATE_FORMAT_CUSTOMVIEW' => 'd-m-Y',
		'Custom' => 'Personnalisé',
		'Previous FY' => 'Année précédente',
		'Current FY' => 'Cette année',
		'Next FY' => 'L\'année prochaine',
		'Previous FQ' => 'Premier trimestre, année précédente',
		'Current FQ' => 'Trimestre courant, année précédente',
		'Next FQ' => 'Prochain trimestre, année précédente',
		'Yesterday' => 'Hier',
		'Today' => 'Aujourd\'hui',
		'Tomorrow' => 'Demain',
		'Last Week' => 'La semaine dernière',
		'Current Week' => 'Cette semaine',
		'Next Week' => 'La semaine prochaine',
		'Last Month' => 'Le mois dernier',
		'Current Month' => 'Mois en cours',
		'Next Month' => 'Le mois prochain',
		'Last 7 Days' => 'Les 7 derniers jours',
		'Last 30 Days' => 'Les 30 derniers jours',
		'Last 60 Days' => 'Les 60 derniers jours',
		'Last 90 Days' => 'Les 90 derniers jours',
		'Last 120 Days' => 'Les 120 derniers jours',
		'Next 30 Days' => 'Les 30 prochains jours',
		'Next 60 Days' => 'Les 60 prochains jours',
		'Next 90 Days' => 'Les 90 prochains jours',
		'Next 120 Days' => 'Les 120 prochains jours',
		'equals' => 'égal',
		'contains' => 'Contient',
		'does not contain' => 'Ne contient pas',
		'less than' => 'Inférieur à',
		'greater than' => 'Supérieur à',
		'less or equal' => 'Inférieur ou égal',
		'greater or equal' => 'Supérieur ou égal',
		'Address' => 'Adresse',
		'Information' => 'Détail',
		'Description' => 'Description',
		'Custom Information' => 'Informations personnalisées',
		'- Event Information' => '- Détail activité',
		'- Event Description' => '- Description activité',
		'- Task Information' => '- Détail tâche',
		'- Task Description' => '- Description tâche',
		'Title' => 'Titre',
		'Assigned To' => 'Assigné à',
		'Related to' => 'Relatif à',
		'Priority' => 'Priorité',
		'Product Name' => 'Produit',
		'Severity' => 'Engagement',
		'Status' => 'Statut',
		'Category' => 'Catégorie',
		'Created Time' => 'Créé le',
		'Modified Time' => 'Modifié le',
		'Attachment' => 'Pièce jointe',
		'First Name' => 'Prénom',
		'Phone' => 'Téléphone',
		'Last Name' => 'Nom',
		'Company' => 'Société',
		'Lead Source' => 'Origine',
		'Website' => 'Site Web',
		'Industry' => 'Secteur',
		'Lead Status' => 'Statut',
		'Annual Revenue' => 'C.A. annuel',
		'Rating' => 'Evaluation',
		'No Of Employees' => 'Effectif',
		'Street' => 'Adresse',
		'Po Box' => 'Boite postale',
		'Postal Code' => 'Code postal',
		'City' => 'Ville',
		'Country' => 'Pays',
		'State' => 'Département',
		'Account Name' => 'Nom compte',
		'Ticker Symbol' => 'Symbole boursier',
		'Other Phone' => 'Téléphone (alt.)',
		'Member Of' => 'Filiale de',
		'Employees' => 'Effectif',
		'Other Email' => 'Autre email',
		'Ownership' => 'Propriétaire',
		'industry' => 'Secteur',
		'SIC Code' => 'Code APE',
		'Email Opt Out' => 'Ne pas contacter par email',
		'Billing Address' => 'Adresse (facturation)',
		'Shipping Address' => 'Adresse (livraison)',
		'Shipping Po Box' => 'Boite postale (livraison)',
		'Billing Po Box' => 'Boite postale (facturation)',
		'Billing City' => 'Ville (facturation)',
		'Shipping City' => 'Ville (livraison)',
		'Billing State' => 'Département (facturation)',
		'Shipping State' => 'Département (livraison)',
		'Billing Code' => 'Code postal (facturation)',
		'Shipping Code' => 'Code postal (livraison)',
		'Shipping Country' => 'Pays (livraison)',
		'Billing Country' => 'Pays (facturation)',
		'Office Phone' => 'Téléphone (bureau)',
		'Home Phone' => 'Téléphone (domicile)',
		'Birthdate' => 'Anniversaire',
		'Reports To' => 'Supérieur hiérarchique',
		'Assistant Phone' => 'Téléphone (assistant)',
		'Do Not Call' => 'Ne pas appleler',
		'Mailing Street' => 'Adresse',
		'Other Street' => 'Adresse (alt.)',
		'Mailing Po Box' => 'Boite postale',
		'Other Po Box' => 'Boite postale (alt.)',
		'Mailing City' => 'Ville',
		'Other City' => 'Ville (alt.)',
		'Mailing State' => 'Département',
		'Other State' => 'Département (alt.)',
		'Mailing Zip' => 'Code postal',
		'Other Zip' => 'Code postal (alt.)',
		'Mailing Country' => 'Pays',
		'Other Country' => 'Pays (alt.)',
		'Potential Name' => 'Objet',
		'Amount' => 'Montant',
		'Expected Close Date' => 'Echéance',
		'Next Step' => 'Etape suivante',
		'Sales Stage' => 'Phase vente',
		'Probability' => 'Probabilité',
		'Subject' => 'Objet',
		'Quote Stage' => 'Phase',
		'Valid Till' => 'Echeance',
		'Team' => 'Equipe',
		'Contact Name' => 'Contact',
		'Carrier' => 'Transporteur',
		'Shipping' => 'Livraison',
		'Inventory Manager' => 'Responsable produit',
		'Customer No' => 'Ref client',
		'Quote Name' => 'Objet',
		'Purchase Order' => 'Commande fournisseur',
		'Due Date' => 'Echéance',
		'Pending' => 'En attente',
		'Sales Commission' => 'Commission',
		'Excise Duty' => 'Remise',
		'Sales Order' => 'Bon de commande',
		'Invoice Date' => 'Date facturation',
		'Product Active' => 'Actif',
		'Product Category' => 'Catégorie',
		'Sales Start Date' => 'Mise en vente',
		'Sales End Date' => 'Fin de vente',
		'Support Start Date' => 'Début de support',
		'Support Expiry Date' => 'Date fin support',
		'Vendor Name' => 'Fournisseur',
		'Mfr PartNo' => 'Fournisseur pièce n°',
		'Vendor PartNo' => 'Fournisseur pièce n°',
		'Serial No' => 'N° de série',
		'Product Sheet' => 'Fiche produit',
		'GL Account' => 'Comptabilité',
		'Price Book Name' => 'Grille tarifaire',
		'Active' => 'Active',
		'Start Date & Time' => 'Date & heure de début',
		'Missing required fields' => 'Des champs requis n\'ont pas été remplis',
		'Campaign Name' => 'Objet',
		'Campaign Type' => 'Type',
		'Product' => 'Produit',
		'Campaign Status' => 'Statut',
		'Expected Revenue' => 'Revenus attendus',
		'Budget Cost' => 'Coût',
		'Actual Cost' => 'Coût actuel',
		'Expected Response' => 'Réponse attendue',
		'Num Sent' => 'Nombre d\'envois',
		'Target Audience' => 'Cible visée',
		'TargetSize' => 'Panel',
		'Sponsor' => 'Sponsor',
		'Expected Sales Count' => 'Ventes attendues',
		'Expected Response Count' => 'Réponses attendues',
		'Expected ROI' => 'ROI attendu',
		'Actual Sales Count' => 'Nb de ventes ',
		'Actual Response Count' => 'Nb de réponses',
		'Actual ROI' => 'ROI',
		'LBL_Select_a_Column' => 'Sélectionnez une colonne',
		'Missing_required_fields' => 'Champs requis manquants',
		'Details' => 'Détails',
		'New_Custom_View' => 'Nouveau filtre',
		'Edit_Custom_View' => 'Editer filtre',
		'LBL_AF_HDR5' => 'Le filtre basique sur le temps vous permet d\'effectuer des tris sur Les dates de création ou Les dates de modifications',
		'Select_Duration' => 'Sélectionnez durée',
		'Simple_Time_Filter' => 'Filtre de temps',
		'Start_Date' => 'Date de début',
		'End_Date' => 'Echéance',
		'LBL_RULE' => 'Règles',
		'not equal to' => 'Différent de',
		'starts with' => 'Commence par',
		'ends with' => 'Fini par',
		'LBL_SET_AS_PUBLIC' => 'Définir comme public ',
		'LBL_NEW' => 'Nouveau',
		'LBL_EDIT' => 'Editer',
		'LBL_STATUS_PUBLIC_APPROVE' => 'Accepter',
		'LBL_STATUS_PUBLIC_DENY' => 'Interdire',
);
$mod_list_strings = array (
);
?>

==> vtigercrm-5.4.0.tgz: modules/CustomView/language/fr_fr.lang.php <==
<?php
/***********************************************************
*  Module       : CustomView
*  Language     : French
*  Version      : 5.4.0 
*  License      : GPL
*  Author       : ABOnline solutions http://www.vtiger-crm.fr
***********************************************************/

$mod_strings = array (
		'LBL_MODULE_NAME' => 'Filtres',
		'LBL_STEP_1_TITLE' => 'Information',
		'LBL_VIEW_NAME' => 'Nom du filtre :',
		'LBL_SETDEFAULT' => 'Définir par défaut',
		'LBL_LIST_IN_METRICS' => 'Indicateur clé',
		'LBL_STEP_2_TITLE' => 'Sélectionner colonne',
		'LBL_STEP_3_TITLE' => 'Filtres standards',
		'LBL_STEP_4_TITLE' => 'Filtres avancés',
		'LBL_STEP_5_TITLE' => 'Information d\'accès',
		'LBL_SF_COLUMNS' => 'Colonne',
		'LBL_SF_STARTDATE' => 'Date de début',
		'LBL_SF_ENDDATE' => 'Date de fin',
		'LBL_AF_HDR1' => 'Définir les options de recherche.',
		'LBL_AF_HDR2' => 'Vous pouvez utiliser le filtre "or" en saisissant simplement plusieurs conditions.',
		'LBL_AF_HDR3' => 'Vous pouvez saisir jusqu\'à 10 conditions, séparées par des virgules. Par exemple : CA, NY, TX, FL pour rechercher CA ou NY ou TX ou FL.',
		'LBL_AF_HDR4' => 'Si \"Type d\'activité\" est sélectionné, donnez une de ces valeurs \"Call\",\"Meeting\" ou \"Task\".',
		'LBL_NONE' => 'Aucun',
		'View_Name' => 'Nom du filtre',
		'LBL_AND' => 'et',
		'LBL_DATE_FORMAT_CUSTOMVIEW' => 'd-m-Y',
		'Custom' => 'Personnalisé',
		'Previous FY' => 'Année précédente',
		'Current FY' => 'Cette année',
		'Next FY' => 'L\'année prochaine',
		'Previous FQ' => 'Premier trimestre, année précédente',
		'Current FQ' => 'Trimestre courant, année précédente',
		'Next FQ' => 'Prochain trimestre, année précédente',
		'Yesterday' => 'Hier',
		'Today' => 'Aujourd\'hui',
		'Tomorrow' => 'Demain',
		'Last Week' => 'La semaine dernière',
		'Current Week' => 'Cette semaine',
		'Next Week' => 'La semaine prochaine',
		'Last Month' => 'Le mois dernier',
		'Current Month' => 'Mois en cours',
		'Next Month' => 'Le mois prochain',
		'Last 7 Days' => 'Les 7 derniers jours',
		'Last 30 Days' => 'Les 30 derniers jours',
		'Last 60 Days' => 'Les 60 derniers jours',
		'Last 90 Days' => 'Les 90 derniers jours',
		'Last 120 Days' => 'Les 120 derniers jours',
		'Next 30 Days' => 'Les 30 prochains jours',
		'Next 60 Days' => 'Les 60 prochains jours',
		'Next 90 Days' => 'Les 90 prochains jours',
		'Next 120 Days' => 'Les 120 prochains jours',
		'equals' => 'égal',
		'contains' => 'Contient',
		'does not contain' => 'Ne contient pas',
		'less than' => 'Inférieur à',
		'greater than' => 'Supérieur à',
		'less or equal' => 'Inférieur ou égal',
		'greater or equal' => 'Supérieur ou égal',
		'Address' => 'Adresse',
		'Information' => 'Détail',
		'Description' => 'Description',
		'Custom Information' => 'Informations personnalisées',
		'- Event Information' => '- Détail activité',
		'- Event Description' => '- Description activité',
		'- Task Information' => '- Détail tâche',
		'- Task Description' => '- Description tâche',
		'Title' => 'Titre',
		'Assigned To' => 'Assigné à',
		'Related to' => 'Relatif à',
		'Priority' => 'Priorité',
		'Product Name' => 'Produit',
		'Severity' => 'Engagement',
		'Status' => 'Statut',
		'Category' => 'Catégorie',
		'Created Time' => 'Créé le',
		'Modified Time' => 'Modifié le',
		'Attachment' => 'Pièce jointe',
		'First Name' => 'Prénom',
		'Phone' => 'Téléphone',
		'Last Name' => 'Nom',
		'Company' => 'Société',
		'Lead Source' => 'Origine',
		'Website' => 'Site Web',
		'Industry' => 'Secteur',
		'Lead Status' => 'Statut',
		'Annual Revenue' => 'C.A. annuel',
		'Rating' => 'Evaluation',
		'No Of Employees' => 'Effectif',
		'Street' => 'Adresse',
		'Po Box' => 'Boite postale',
		'Postal Code' => 'Code postal',
		'City' => 'Ville',
		'Country' => 'Pays',
		'State' => 'Département',
		'Account Name' => 'Nom compte',
		'Ticker Symbol' => 'Symbole boursier',
		'Other Phone' => 'Téléphone (alt.)',
		'Member Of' => 'Filiale de',
		'Employees' => 'Effectif',
		'Other Email' => 'Autre email',
		'Ownership' => 'Propriétaire',
		'industry' => 'Secteur',
		'SIC Code' => 'Code APE',
		'Email Opt Out' => 'Ne pas contacter par email',
		'Billing Address' => 'Adresse (facturation)',
		'Shipping Address' => 'Adresse (livraison)',
		'Shipping Po Box' => 'Boite postale (livraison)',
		'Billing Po Box' => 'Boite postale (facturation)',
		'Billing City' => 'Ville (facturation)',
		'Shipping City' => 'Ville (livraison)',
		'Billing State' => 'Département (facturation)',
		'Shipping State' => 'Département (livraison)',
		'Billing Code' => 'Code postal (facturation)',
		'Shipping Code' => 'Code postal (livraison)',
		'Shipping Country' => 'Pays (livraison)',
		'Billing Country' => 'Pays (facturation)',
		'Office Phone' => 'Téléphone (bureau)',
		'Home Phone' => 'Téléphone (domicile)',
		'Birthdate' => 'Anniversaire',
		'Reports To' => 'Supérieur hiérarchique',
		'Assistant Phone' => 'Téléphone (assistant)',
		'Do Not Call' => 'Ne pas appleler',
		'Mailing Street' => 'Adresse',
		'Other Street' => 'Adresse (alt.)',
		'Mailing Po Box' => 'Boite postale',
		'Other Po Box' => 'Boite postale (alt.)',
		'Mailing City' => 'Ville',
		'Other City' => 'Ville (alt.)',
		'Mailing State' => 'Département',
		'Other State' => 'Département (alt.)',
		'Mailing Zip' => 'Code postal',
		'Other Zip' => 'Code postal (alt.)',
		'Mailing Country' => 'Pays',
		'Other Country' => 'Pays (alt.)',
		'Potential Name' => 'Objet',
		'Amount' => 'Montant',
		'Expected Close Date' => 'Echéance',
		'Next Step' => 'Etape suivante',
		'Sales Stage' => 'Phase vente',
		'Probability' => 'Probabilité',
		'Subject' => 'Objet',
		'Quote Stage' => 'Phase',
		'Valid Till' => 'Echeance',
		'Team' => 'Equipe',
		'Contact Name' => 'Contact',
		'Carrier' => 'Transporteur',
		'Shipping' => 'Livraison',
		'Inventory Manager' => 'Responsable produit',
		'Customer No' => 'Ref client',
		'Quote Name' => 'Objet',
		'Purchase Order' => 'Commande fournisseur',
		'Due Date' => 'Echéance',
		'Pending' => 'En attente',
		'Sales Commission' => 'Commission',
		'Excise Duty' => 'Remise',
		'Sales Order' => 'Bon de commande',
		'Invoice Date' => 'Date facturation',
		'Product Active' => 'Actif',
		'Product Category' => 'Catégorie',
		'Sales Start Date' => 'Mise en vente',
		'Sales End Date' => 'Fin de vente',
		'Support Start Date' => 'Début de support',
		'Support Expiry Date' => 'Date fin support',
		'Vendor Name' => 'Fournisseur',
		'Mfr PartNo' => 'Fournisseur pièce n°',
		'Vendor PartNo' => 'Fournisseur pièce n°',
		'Serial No' => 'N° de série',
		'Product Sheet' => 'Fiche produit',
		'GL Account' => 'Comptabilité',
		'Price Book Name' => 'Grille tarifaire',
		'Active' => 'Active',
		'Start Date & Time' => 'Date & heure de début',
		'Missing required fields' => 'Des champs requis n\'ont pas été remplis',
		'Campaign Name' => 'Objet',
		'Campaign Type' => 'Type',
		'Product' => 'Produit',
		'Campaign Status' => 'Statut',
		'Expected Revenue' => 'Revenus attendus',
		'Budget Cost' => 'Coût',
		'Actual Cost' => 'Coût actuel',
		'Expected Response' => 'Réponse attendue',
		'Num Sent' => 'Nombre d\'envois',
		'Target Audience' => 'Cible visée',
		'TargetSize' => 'Panel',
		'Sponsor' => 'Sponsor',
		'Expected Sales Count' => 'Ventes attendues',
		'Expected Response Count' => 'Réponses attendues',
		'Expected ROI' => 'ROI attendu',
		'Actual Sales Count' => 'Nb de ventes ',
		'Actual Response Count' => 'Nb de réponses',
		'Actual ROI' => 'ROI',
		'LBL_Select_a_Column' => 'Sélectionnez une colonne',
		'Missing_required_fields' => 'Champs requis manquants',
		'Details' => 'Détails',
		'New_Custom_View' => 'Nouveau filtre',
		'Edit_Custom_View' => 'Editer filtre',
		'LBL_AF_HDR5' => 'Le filtre basique sur le temps vous permet d\'effectuer des tris sur Les dates de création ou Les dates de modifications',
		'Select_Duration' => 'Sélectionnez durée',
		'Simple_Time_Filter' => 'Filtre de temps',
		'Start_Date' => 'Date de début',
		'End_Date' => 'Echéance',
		'LBL_RULE' => 'Règles',
		'not equal to' => 'Différent de',
		'starts with' => 'Commence par',
		'ends with' => 'Fini par',
		'LBL_SET_AS_PUBLIC' => 'Définir comme public ',
		'LBL_NEW' => 'Nouveau',
		'LBL_EDIT' => 'Editer',
		'LBL_STATUS_PUBLIC_APPROVE' => 'Accepter',
		'LBL_STATUS_PUBLIC_DENY' => 'Interdire',
		'LBL_ADVANCED_FILTER' => 'Règle',
);
$mod_list_strings = array (
);
?>
